@@ -253,6 +253,33 @@ class CordClientDataset(CordClient):
                 message='An error has occurred during image group creation.'
             )
 
+    def delete_image_group(self, data_hash: str):
+        """
+        Create an image group in Cord storage.
+
+        Args:
+            self: Cord client object.
+            data_hash: the hash of the image group you'd like to delete
+        """
+        self._querier.basic_delete(
+            ImageGroup,
+            uid=data_hash
+        )
+
+    def delete_data(self, data_hashes: list):
+        """
+        Delete a video/image group from a dataset.
+
+        Args:
+            self: Cord client object.
+            data_hashes: list of hash of the videos/image_groups you'd like to delete, all should belong to the same
+             dataset
+        """
+        self._querier.basic_delete(
+            Video,
+            uid=data_hashes
+        )
+
 
 class CordClientProject(CordClient):
     def get_project(self):
